self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "url": "/frontend_latest/chunk.82decdfb759e59df6a51.js"
  },
  {
    "url": "/frontend_latest/chunk.f4fa9369c89a713f8e92.js"
  },
  {
    "url": "/frontend_latest/chunk.7c068b1070569ad92039.js"
  },
  {
    "url": "/frontend_latest/chunk.5ae3db76b82c3833eb14.js"
  },
  {
    "url": "/frontend_latest/chunk.583189d901d0320aac90.js"
  },
  {
    "url": "/frontend_latest/chunk.6fb835617932441adf35.js"
  },
  {
    "url": "/frontend_latest/chunk.3aaa39e4ad7c277e2e58.js"
  },
  {
    "url": "/frontend_latest/chunk.6b49f9771d1b803e5c80.js"
  },
  {
    "url": "/frontend_latest/chunk.7a1455deabd7d43e9e05.js"
  },
  {
    "url": "/frontend_latest/chunk.7fdeed4bdc41e8448a71.js"
  },
  {
    "url": "/frontend_latest/chunk.192239ddef2670ce505b.js"
  },
  {
    "url": "/frontend_latest/chunk.6fce30c0f53288e490d9.js"
  },
  {
    "url": "/frontend_latest/chunk.8bf50251867005f1c1e5.js"
  },
  {
    "url": "/frontend_latest/chunk.60a9348210ae8870eb4c.js"
  },
  {
    "url": "/frontend_latest/chunk.2a0b7cfecf0bb2d5ab29.js"
  },
  {
    "url": "/frontend_latest/chunk.61abb7dfa96bba5ed8a2.js"
  },
  {
    "url": "/frontend_latest/chunk.77a38ffced35e3fe9a8f.js"
  },
  {
    "url": "/frontend_latest/chunk.8fcd071fbaf5a3514f63.js"
  },
  {
    "url": "/frontend_latest/chunk.72f55ab4dd4090e59968.js"
  },
  {
    "url": "/frontend_latest/chunk.c2234f7a23327b231f8b.js"
  },
  {
    "url": "/frontend_latest/chunk.c1843b529a0d08ae9ee6.js"
  },
  {
    "url": "/frontend_latest/chunk.375daa6a4b68ccd89dbd.js"
  },
  {
    "url": "/frontend_latest/chunk.6e34dfedda9a4c677876.js"
  },
  {
    "url": "/frontend_latest/chunk.d776e82ca2c19a8a5cf9.js"
  },
  {
    "url": "/frontend_latest/chunk.47edc327a4e2a41e55da.js"
  },
  {
    "revision": "e0ed1fe962bedb8224f2",
    "url": "/frontend_latest/app.e0ed1fe9.js"
  },
  {
    "url": "/frontend_latest/chunk.e85118e34255e35fe900.js"
  },
  {
    "revision": "ec6ae1daf7b3f9ce9501",
    "url": "/frontend_latest/authorize.ec6ae1da.js"
  },
  {
    "url": "/frontend_latest/chunk.5ac4259fc9033b90a736.js"
  },
  {
    "url": "/frontend_latest/chunk.f7472e9a83dc425aa196.js"
  },
  {
    "url": "/frontend_latest/chunk.1f1ba218d20c92cbc739.js"
  },
  {
    "url": "/frontend_latest/chunk.9ee7fe3413becb5b4e42.js"
  },
  {
    "url": "/frontend_latest/chunk.08142d11881d0d42c7a7.js"
  },
  {
    "url": "/frontend_latest/chunk.c99ac93c6e1ab5fa3e12.js"
  },
  {
    "url": "/frontend_latest/chunk.3b41cb8e8f09b11fc47c.js"
  },
  {
    "revision": "1d82bf3ec6d5a08f0b30",
    "url": "/frontend_latest/compatibility.1d82bf3e.js"
  },
  {
    "url": "/frontend_latest/chunk.7103659466705cfa1392.js"
  },
  {
    "url": "/frontend_latest/chunk.9e100231961ab07eb544.js"
  },
  {
    "revision": "1c60a1f70fa15e7540e5",
    "url": "/frontend_latest/core.1c60a1f7.js"
  },
  {
    "revision": "f69201ff73f923d11b30",
    "url": "/frontend_latest/custom-panel.f69201ff.js"
  },
  {
    "url": "/frontend_latest/chunk.f7864598774450abf9e8.js"
  },
  {
    "url": "/frontend_latest/chunk.3f3ccdeb48adf3934ddf.js"
  },
  {
    "url": "/frontend_latest/chunk.a3c9b96f7ad32b4a8a80.js"
  },
  {
    "url": "/frontend_latest/chunk.6a574660598f8928fb88.js"
  },
  {
    "url": "/frontend_latest/chunk.c921ca342529ad98fa04.js"
  },
  {
    "url": "/frontend_latest/chunk.6d161c385fe044948dc9.js"
  },
  {
    "url": "/frontend_latest/chunk.8159dd965c32e71d83eb.js"
  },
  {
    "url": "/frontend_latest/chunk.6add40244c27b150a692.js"
  },
  {
    "url": "/frontend_latest/chunk.c5ffe99456c0bd7edf0a.js"
  },
  {
    "url": "/frontend_latest/chunk.c074108ed14a85c87838.js"
  },
  {
    "url": "/frontend_latest/chunk.d7d99344c60d7252034a.js"
  },
  {
    "url": "/frontend_latest/chunk.654bf467484cafea6a62.js"
  },
  {
    "url": "/frontend_latest/chunk.e6c234694620ac3c98a5.js"
  },
  {
    "revision": "31f02e18923315313c6b",
    "url": "/frontend_latest/hass-icons.31f02e18.js"
  },
  {
    "url": "/frontend_latest/chunk.2ac090fc2c205f3058f6.js"
  },
  {
    "url": "/frontend_latest/chunk.18786b0166643ff0fe5e.js"
  },
  {
    "url": "/frontend_latest/chunk.e10f2ac1a62230d1e061.js"
  },
  {
    "url": "/frontend_latest/chunk.e43f09664318679ae242.js"
  },
  {
    "url": "/frontend_latest/chunk.a707cb888bf0d24e5da7.js"
  },
  {
    "url": "/frontend_latest/chunk.c3cb62fdb1cb5a9ab67b.js"
  },
  {
    "url": "/frontend_latest/chunk.072c54cde82c0f8fb7f6.js"
  },
  {
    "url": "/frontend_latest/chunk.8fb68c0a4610e6760b0a.js"
  },
  {
    "url": "/frontend_latest/chunk.d8a08a2dc1541383501a.js"
  },
  {
    "url": "/frontend_latest/chunk.0296c9b7eb339d58bdb7.js"
  },
  {
    "url": "/frontend_latest/chunk.88ac2e95debb760d4345.js"
  },
  {
    "url": "/frontend_latest/chunk.ac126ba89ae1621e8db9.js"
  },
  {
    "url": "/frontend_latest/chunk.e4a384fbe09ef58df882.js"
  },
  {
    "url": "/frontend_latest/chunk.bb93114bd55211a1ac3b.js"
  },
  {
    "url": "/frontend_latest/chunk.dc017c233af5f9d43854.js"
  },
  {
    "url": "/frontend_latest/chunk.e09b718734c806acce4e.js"
  },
  {
    "url": "/frontend_latest/chunk.9a83b2b9fa00f0867cd9.js"
  },
  {
    "url": "/frontend_latest/chunk.30eebc02065a95bf8b07.js"
  },
  {
    "url": "/frontend_latest/chunk.91a67002badb70dcae45.js"
  },
  {
    "url": "/frontend_latest/chunk.d94f23348f1ab00903b1.js"
  },
  {
    "url": "/frontend_latest/chunk.f930743622fce3ec1f36.js"
  },
  {
    "url": "/frontend_latest/chunk.ad2eff81a960ea0b592e.js"
  },
  {
    "url": "/frontend_latest/chunk.1eb8929d58c2a856ff70.js"
  },
  {
    "url": "/frontend_latest/chunk.eedc9b2929c5efeb4e62.js"
  },
  {
    "url": "/frontend_latest/chunk.4a14c48e867cf53253c5.js"
  },
  {
    "url": "/frontend_latest/chunk.278776a9e6afca64a0db.js"
  },
  {
    "url": "/frontend_latest/chunk.f022bf9f19dd5be2afeb.js"
  },
  {
    "url": "/frontend_latest/chunk.1553e8092331a06af85f.js"
  },
  {
    "url": "/frontend_latest/chunk.f1520ace6db6dd3bcc7b.js"
  },
  {
    "url": "/frontend_latest/chunk.2e8e21a5a02432ccf1ba.js"
  },
  {
    "url": "/frontend_latest/chunk.5fd5eca4e19f126fc667.js"
  },
  {
    "url": "/frontend_latest/chunk.9fe76f57d72f684293fb.js"
  },
  {
    "url": "/frontend_latest/chunk.152028016e590dba24ad.js"
  },
  {
    "url": "/frontend_latest/chunk.9cf68c7dd7ed45e54acc.js"
  },
  {
    "url": "/frontend_latest/chunk.445a62b0b71585b53e88.js"
  },
  {
    "url": "/frontend_latest/chunk.d4725603e97d7b4babf9.js"
  },
  {
    "url": "/frontend_latest/chunk.9dd634a8f192ca973d4e.js"
  },
  {
    "url": "/frontend_latest/chunk.0f3dd22a83de90129d8d.js"
  },
  {
    "url": "/frontend_latest/chunk.0026972cee06426c095c.js"
  },
  {
    "url": "/frontend_latest/chunk.b2b5251375db6d71c664.js"
  },
  {
    "url": "/frontend_latest/chunk.37f67d3cb3baa12fd194.js"
  },
  {
    "url": "/frontend_latest/chunk.6bb6146bf4c851cb974c.js"
  },
  {
    "revision": "041e38225b65c2a0a7fd",
    "url": "/frontend_latest/onboarding.041e3822.js"
  },
  {
    "url": "/frontend_latest/chunk.df9f013823feb97e5d04.js"
  },
  {
    "url": "/frontend_latest/chunk.d26a628fcaf1fd49483d.js"
  },
  {
    "url": "/frontend_latest/chunk.07d67b6f5b0ee2e3bb79.js"
  },
  {
    "url": "/frontend_latest/chunk.8e7f8c4d8a11d25c2c48.js"
  },
  {
    "url": "/frontend_latest/chunk.d357c16b62cea71f32bc.js"
  },
  {
    "url": "/frontend_latest/chunk.5333a27aa34dc15e6a94.js"
  },
  {
    "url": "/frontend_latest/chunk.285d458c231b9932c928.js"
  },
  {
    "url": "/frontend_latest/chunk.6912f3a013d763976848.js"
  },
  {
    "url": "/frontend_latest/chunk.b9eae38c5646291415c5.js"
  },
  {
    "url": "/frontend_latest/chunk.db3e854919729c36b06a.js"
  },
  {
    "url": "/frontend_latest/chunk.59e13a730f6aeea0554a.js"
  },
  {
    "url": "/frontend_latest/chunk.cc2645f919307a7f4451.js"
  },
  {
    "url": "/frontend_latest/chunk.0d75436688e9c6544a18.js"
  },
  {
    "url": "/frontend_latest/chunk.df23deadfdea39f12614.js"
  },
  {
    "url": "/frontend_latest/chunk.b1f1bd80f07824f0d668.js"
  },
  {
    "url": "/frontend_latest/chunk.e3622b29fd22147b90f4.js"
  },
  {
    "url": "/frontend_latest/chunk.f78c370a86d4fda5ee05.js"
  },
  {
    "url": "/frontend_latest/chunk.599fbae27e97cb177754.js"
  },
  {
    "url": "/frontend_latest/chunk.11a49f9bd4d1e4f53f52.js"
  },
  {
    "url": "/frontend_latest/chunk.4ff9a1d9034d0245730d.js"
  },
  {
    "url": "/frontend_latest/chunk.742179109a1f77f74a33.js"
  },
  {
    "url": "/frontend_latest/chunk.97dd409b3d467eb29a05.js"
  },
  {
    "url": "/frontend_latest/chunk.9f4ab6df8909556e5566.js"
  },
  {
    "url": "/frontend_latest/chunk.2280050c63188f3f0c50.js"
  },
  {
    "url": "/frontend_latest/chunk.b38aebb4ea485ca4d432.js"
  },
  {
    "url": "/frontend_latest/chunk.45d3bbc2d118612ef4f4.js"
  },
  {
    "url": "/frontend_latest/chunk.b5641405c282eab02cf8.js"
  },
  {
    "url": "/frontend_latest/chunk.1bda991bda8978a8871f.js"
  },
  {
    "url": "/frontend_latest/chunk.2ec210ebda1b39346db9.js"
  },
  {
    "url": "/frontend_latest/chunk.76a1ce192b48d43c6619.js"
  },
  {
    "url": "/frontend_latest/chunk.43e791619753b6d6ff7d.js"
  },
  {
    "url": "/frontend_latest/chunk.f7726ebafc48bfab5731.js"
  },
  {
    "url": "/frontend_latest/chunk.539876931fc26ac8293c.js"
  },
  {
    "url": "/frontend_latest/chunk.25115ced5664636a5668.js"
  },
  {
    "url": "/frontend_latest/chunk.ca3941396e213a32c9b9.js"
  },
  {
    "url": "/frontend_latest/chunk.5f56fa4c813fb93d5ab9.js"
  },
  {
    "url": "/frontend_latest/chunk.07d439f564d54607b5f1.js"
  },
  {
    "url": "/frontend_latest/chunk.cc692e5cebde711bd580.js"
  },
  {
    "url": "/frontend_latest/chunk.459fe588dc879a21c6d3.js"
  },
  {
    "url": "/frontend_latest/chunk.4eb7992e41edbd6abd2a.js"
  },
  {
    "url": "/frontend_latest/chunk.f2a5a3f50191f912aaa7.js"
  },
  {
    "url": "/frontend_latest/chunk.287ed66ba99bcb5da015.js"
  },
  {
    "url": "/frontend_latest/chunk.c80af2635a241b283119.js"
  },
  {
    "url": "/frontend_latest/chunk.c4806bcbb4f24f2b3730.js"
  },
  {
    "url": "/frontend_latest/chunk.ad6b9376f2e68aab5109.js"
  },
  {
    "url": "/frontend_latest/chunk.03eaa1678d7eacb27fc4.js"
  },
  {
    "url": "/frontend_latest/chunk.f17c36e130fc42bc5720.js"
  },
  {
    "url": "/frontend_latest/chunk.c96aebdedcf633afc279.js"
  },
  {
    "url": "/frontend_latest/chunk.93d534ffb66e469e779a.js"
  },
  {
    "url": "/frontend_latest/chunk.66c34899b610a20e3a47.js"
  },
  {
    "url": "/frontend_latest/chunk.f48fdea1f7fe32fc27d1.js"
  },
  {
    "url": "/frontend_latest/chunk.b8c90d03f3d658cdf13f.js"
  },
  {
    "url": "/frontend_latest/chunk.21b59fa8cb79124d8ae0.js"
  },
  {
    "url": "/frontend_latest/chunk.3bf9fcf06f39f27ade66.js"
  },
  {
    "url": "/frontend_latest/chunk.0da2ef11a2b8c479fe59.js"
  },
  {
    "url": "/frontend_latest/chunk.8454018c8377aa1df08a.js"
  },
  {
    "url": "/frontend_latest/chunk.fa0e595a3845e86156e8.js"
  },
  {
    "url": "/frontend_latest/chunk.45950cbcb9f435bb8000.js"
  },
  {
    "url": "/frontend_latest/chunk.c87215bf7eb3f2024c85.js"
  },
  {
    "url": "/frontend_latest/chunk.49082cdaeb0cedde5930.js"
  },
  {
    "url": "/frontend_latest/chunk.b595f5956835608e2efa.js"
  },
  {
    "url": "/frontend_latest/chunk.1854363900f17b4057b6.js"
  },
  {
    "url": "/frontend_latest/chunk.70ae9da91ec00a4b12eb.js"
  },
  {
    "url": "/frontend_latest/chunk.4a4206732bf0fbdcb09f.js"
  },
  {
    "url": "/frontend_latest/chunk.da9f140f12013afaf812.js"
  },
  {
    "url": "/frontend_latest/chunk.ad2c14a48d0118122442.js"
  },
  {
    "url": "/frontend_latest/chunk.1c97c3ea19b6259ff559.js"
  },
  {
    "url": "/frontend_latest/chunk.a25c12d864f8bbfd7656.js"
  },
  {
    "url": "/frontend_latest/chunk.08c158b0c21a4b7b6dd6.js"
  },
  {
    "url": "/frontend_latest/chunk.8b90a1565b095e504fd6.js"
  },
  {
    "url": "/frontend_latest/chunk.9c211c588ed9274889aa.js"
  },
  {
    "url": "/frontend_latest/chunk.d6a549539c06276ddbf3.js"
  },
  {
    "url": "/frontend_latest/chunk.6b765fb6af2a5bb751f0.js"
  },
  {
    "url": "/frontend_latest/chunk.252802ceea74fc027065.js"
  },
  {
    "url": "/frontend_latest/chunk.d24dd43ba8d28af6a0dd.js"
  },
  {
    "url": "/frontend_latest/chunk.63e62aa918066f9fb3fd.js"
  },
  {
    "url": "/frontend_latest/chunk.85c31de49d207f34b2b8.js"
  },
  {
    "url": "/frontend_latest/chunk.c5c5540dac7e2dbc5642.js"
  },
  {
    "url": "/frontend_latest/chunk.9596480506d64f25f863.js"
  },
  {
    "url": "/frontend_latest/chunk.2938089b576ae5746328.js"
  },
  {
    "url": "/frontend_latest/chunk.588c8d7cff3e7e4805f9.js"
  },
  {
    "url": "/frontend_latest/chunk.82c05b110c5856e75f35.js"
  },
  {
    "url": "/frontend_latest/chunk.90cf81e0a4d13141c14d.js"
  },
  {
    "url": "/frontend_latest/chunk.f3733e44b1bd76d8db22.js"
  },
  {
    "url": "/frontend_latest/chunk.7210ea9752dfcfc87ebb.js"
  },
  {
    "url": "/frontend_latest/chunk.01ddeaed1a534f270164.js"
  },
  {
    "url": "/frontend_latest/chunk.971864f628a48cf1dd6b.js"
  },
  {
    "url": "/frontend_latest/chunk.33c109a4249f1af2a268.js"
  },
  {
    "url": "/frontend_latest/chunk.9134a6e60ebab2a504c5.js"
  },
  {
    "url": "/frontend_latest/chunk.58a45f6ccf16a615b442.js"
  },
  {
    "url": "/frontend_latest/chunk.84070ba6be6047d679c9.js"
  },
  {
    "url": "/frontend_latest/chunk.d5b60cbbf43651151b52.js"
  },
  {
    "url": "/frontend_latest/chunk.29b1aa4101e15f5d53db.js"
  },
  {
    "url": "/frontend_latest/chunk.fad3636b4ee8216fc678.js"
  },
  {
    "url": "/frontend_latest/chunk.9413be846b4c65f534ef.js"
  },
  {
    "url": "/frontend_latest/chunk.65fffb1d20bfb7cbc6be.js"
  },
  {
    "url": "/frontend_latest/chunk.6e6cb29c328fa8866817.js"
  },
  {
    "url": "/frontend_latest/chunk.a0f70ea807490b52262a.js"
  },
  {
    "url": "/frontend_latest/chunk.722946699b36a59e3a4b.js"
  },
  {
    "url": "/frontend_latest/chunk.07275c2283d42982989e.js"
  },
  {
    "url": "/frontend_latest/chunk.60790404efc85cf71d1f.js"
  },
  {
    "url": "/frontend_latest/chunk.1261296062b510a58179.js"
  },
  {
    "url": "/frontend_latest/chunk.ecd206b745211bd4ad05.js"
  },
  {
    "url": "/frontend_latest/chunk.686f8f42a28ec50a1012.js"
  },
  {
    "url": "/frontend_latest/chunk.b2232981bdfa192965c2.js"
  },
  {
    "url": "/frontend_latest/chunk.37582f5fae2b54107f9e.js"
  },
  {
    "url": "/frontend_latest/chunk.0ee961ba06c1aa56103c.js"
  },
  {
    "url": "/frontend_latest/chunk.aa412137c8909f5f5c6c.js"
  },
  {
    "url": "/frontend_latest/chunk.73710fbc030092daebc5.js"
  },
  {
    "url": "/frontend_latest/chunk.15e42205f9dcdd9ee53a.js"
  },
  {
    "url": "/frontend_latest/chunk.8a75578229273560679c.js"
  },
  {
    "url": "/frontend_latest/chunk.9692cef88c8f71ddb073.js"
  },
  {
    "url": "/frontend_latest/chunk.c940f7d59d248d46181b.js"
  },
  {
    "url": "/frontend_latest/chunk.d5e7eccf1c87343693ba.js"
  },
  {
    "url": "/frontend_latest/chunk.eac0482fe5d022601219.js"
  },
  {
    "url": "/frontend_latest/chunk.a7421453c219a869e323.js"
  },
  {
    "url": "/frontend_latest/chunk.8e5b70585de92fa96e47.js"
  },
  {
    "url": "/frontend_latest/chunk.5854bac30fd4779fdbdb.js"
  },
  {
    "url": "/frontend_latest/chunk.e940ce41b5d12212f168.js"
  },
  {
    "url": "/frontend_latest/chunk.0b359d081600c7f5d105.js"
  },
  {
    "url": "/frontend_latest/chunk.6dc818249e77c8e75494.js"
  },
  {
    "url": "/frontend_latest/chunk.74b39bd0508d0e421a53.js"
  },
  {
    "url": "/frontend_latest/chunk.85a4bb5aaf278d706fc3.js"
  },
  {
    "url": "/frontend_latest/chunk.623d990750fb02e5576a.js"
  },
  {
    "url": "/frontend_latest/chunk.f9a78e32fada191cf218.js"
  },
  {
    "url": "/frontend_latest/chunk.2474650218572ea9bea7.js"
  },
  {
    "url": "/frontend_latest/chunk.6db8eaf9dc2f009dc5c8.js"
  },
  {
    "url": "/frontend_latest/chunk.137c0779bcd0879ab9aa.js"
  },
  {
    "url": "/frontend_latest/chunk.1fb5d40e3bbbc444e874.js"
  },
  {
    "url": "/frontend_latest/chunk.183830310ceec3163e61.js"
  },
  {
    "url": "/frontend_latest/chunk.a3ed9ddb93c4d3f18028.js"
  },
  {
    "url": "/frontend_latest/chunk.7a69a96c32885b701d57.js"
  },
  {
    "url": "/frontend_latest/chunk.bebfde22c9247ced8c96.js"
  },
  {
    "revision": "28378efe5e7ce82ea015229db29559ad",
    "url": "/frontend_latest/6737f0a2766239dca152.worker.js"
  },
  {
    "revision": "c9fbef9dda6fb8edc248bf00d7d7a13b",
    "url": "/frontend_latest/b00f0d0b332c52e082ce.worker.js"
  },
  {
    "revision": "b5f5f95138ea6b44d0fbdb4fb87443a5",
    "url": "/static/translations/en-80e56d3cbcfc48bacf116bcc84399a73.json"
  },
  {
    "revision": "84479b5df4cf4203443472f0739c3f6d",
    "url": "/static/translations/config/en-80e56d3cbcfc48bacf116bcc84399a73.json"
  },
  {
    "revision": "d1bc7e76a858e7e30666dfaa076eccf9",
    "url": "/static/translations/history/en-80e56d3cbcfc48bacf116bcc84399a73.json"
  },
  {
    "revision": "60530e55d10c5d69375fb0f9036b22f3",
    "url": "/static/translations/logbook/en-80e56d3cbcfc48bacf116bcc84399a73.json"
  },
  {
    "revision": "dfc5c89d99f2655a9468c103c2105728",
    "url": "/static/translations/mailbox/en-80e56d3cbcfc48bacf116bcc84399a73.json"
  },
  {
    "revision": "275c86eb0b998d5d6b580c96d5f88e06",
    "url": "/static/translations/profile/en-80e56d3cbcfc48bacf116bcc84399a73.json"
  },
  {
    "revision": "ef20f1a8e5847407950c9d13a462d4d0",
    "url": "/static/translations/shopping-list/en-80e56d3cbcfc48bacf116bcc84399a73.json"
  },
  {
    "revision": "c382679aa78abd3caa42102499a7d7f8",
    "url": "/static/translations/page-authorize/en-80e56d3cbcfc48bacf116bcc84399a73.json"
  },
  {
    "revision": "bb32da3220547835c4a9e5447874935c",
    "url": "/static/translations/page-demo/en-80e56d3cbcfc48bacf116bcc84399a73.json"
  },
  {
    "revision": "4e3a171310eea2b4eb104d52b48ecd33",
    "url": "/static/translations/page-onboarding/en-80e56d3cbcfc48bacf116bcc84399a73.json"
  },
  {
    "revision": "3d2f5855aef912916e70f91b2a47bf77",
    "url": "/static/translations/developer-tools/en-80e56d3cbcfc48bacf116bcc84399a73.json"
  },
  {
    "revision": "8413bc5aa8329394d55ba04011a9adae",
    "url": "/static/icons/favicon-192x192.png"
  },
  {
    "revision": "d989a5d0aebf51177bb9efe546d7579f",
    "url": "/static/fonts/roboto/Roboto-Light.woff2"
  },
  {
    "revision": "b635e4fd4c9a33a2a6297fd72530feb9",
    "url": "/static/fonts/roboto/Roboto-Medium.woff2"
  },
  {
    "revision": "0cf968acbe3aa998772842b812a73aaf",
    "url": "/static/fonts/roboto/Roboto-Regular.woff2"
  },
  {
    "revision": "448f4ffaa9adbd0786c792132db8b831",
    "url": "/static/fonts/roboto/Roboto-Bold.woff2"
  }
]);