(self.webpackJsonp=self.webpackJsonp||[]).push([[24],{570:function(e,t,r){"use strict";Object.defineProperty(t,"__esModule",{value:!0});t.ContentRect=function(e){if("getBBox"in e){var t=e.getBBox();return Object.freeze({height:t.height,left:0,top:0,width:t.width})}var r=window.getComputedStyle(e);return Object.freeze({height:parseFloat(r.height||"0"),left:parseFloat(r.paddingLeft||"0"),top:parseFloat(r.paddingTop||"0"),width:parseFloat(r.width||"0")})}},765:function(e,t,r){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var n=r(570),i=function(){function e(e){this.target=e,this.$$broadcastWidth=this.$$broadcastHeight=0}return Object.defineProperty(e.prototype,"broadcastWidth",{get:function(){return this.$$broadcastWidth},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"broadcastHeight",{get:function(){return this.$$broadcastHeight},enumerable:!0,configurable:!0}),e.prototype.isActive=function(){var e=n.ContentRect(this.target);return!!e&&(e.width!==this.broadcastWidth||e.height!==this.broadcastHeight)},e}();t.ResizeObservation=i},766:function(e,t,r){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var n=r(570),i=function(){return function(e){this.target=e,this.contentRect=n.ContentRect(e)}}();t.ResizeObserverEntry=i},840:function(e,t,r){"use strict";Object.defineProperty(t,"__esModule",{value:!0});var n=r(765),i=r(766),o=[],a=function(){function e(e){this.$$observationTargets=[],this.$$activeTargets=[],this.$$skippedTargets=[];var t=function(e){if(void 0===e)return"Failed to construct 'ResizeObserver': 1 argument required, but only 0 present.";if("function"!=typeof e)return"Failed to construct 'ResizeObserver': The callback provided as parameter 1 is not a function."}(e);if(t)throw TypeError(t);this.$$callback=e,o.push(this)}return e.prototype.observe=function(e){var t=s("observe",e);if(t)throw TypeError(t);c(this.$$observationTargets,e)>0||(this.$$observationTargets.push(new n.ResizeObservation(e)),v())},e.prototype.unobserve=function(e){var t=s("unobserve",e);if(t)throw TypeError(t);var r=c(this.$$observationTargets,e);r<0||(this.$$observationTargets.splice(r,1),g())},e.prototype.disconnect=function(){this.$$observationTargets=[],this.$$activeTargets=[]},e}();function s(e,t){return void 0===t?"Failed to execute '"+e+"' on 'ResizeObserver': 1 argument required, but only 0 present.":t instanceof window.Element?void 0:"Failed to execute '"+e+"' on 'ResizeObserver': parameter 1 is not of type 'Element'."}function c(e,t){for(var r=0;r<e.length;r+=1)if(e[r].target===t)return r;return-1}t.ResizeObserver=a;var u,f=function(e){o.forEach(function(t){t.$$activeTargets=[],t.$$skippedTargets=[],t.$$observationTargets.forEach(function(r){r.isActive()&&(d(r.target)>e?t.$$activeTargets.push(r):t.$$skippedTargets.push(r))})})},h=function(){var e=1/0;return o.forEach(function(t){if(t.$$activeTargets.length){var r=[];t.$$activeTargets.forEach(function(t){var n=new i.ResizeObserverEntry(t.target);r.push(n),t.$$broadcastWidth=n.contentRect.width,t.$$broadcastHeight=n.contentRect.height;var o=d(t.target);o<e&&(e=o)}),t.$$callback(r,t),t.$$activeTargets=[]}}),e},d=function(e){for(var t=0;e.parentNode;)e=e.parentNode,t+=1;return t},p=function(){var e,t=0;for(f(t);o.some(function(e){return!!e.$$activeTargets.length});)t=h(),f(t);o.some(function(e){return!!e.$$skippedTargets.length})&&(e=new window.ErrorEvent("ResizeLoopError",{message:"ResizeObserver loop completed with undelivered notifications."}),window.dispatchEvent(e))},v=function(){u||$()},$=function e(){u=window.requestAnimationFrame(function(){p(),e()})},g=function(){u&&!o.some(function(e){return!!e.$$observationTargets.length})&&(window.cancelAnimationFrame(u),u=void 0)};t.install=function(){return window.ResizeObserver=a}}}]);
//# sourceMappingURL=chunk.31dea6f3ecadb5879070.js.map