(self.webpackJsonp=self.webpackJsonp||[]).push([[88],{152:function(e,s,n){"use strict";n.r(s);var a=n(4),b=n(32),l=n(3);l.b.Element=b.a,l.b.html=a.a,window.Polymer=l.b}}]);
//# sourceMappingURL=chunk.445a62b0b71585b53e88.js.map